/*
  Copyright 2003 John Knottenbelt
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
*/

#include "config.h"
#include "connectionmanager.h"
#include "recordconnection.h"
#include "connection.h"

ConnectionManager::~ConnectionManager()
{
  for (ConnectionList::iterator i = connections.begin(); i != connections.end();) {
    Connection *c = *i;
    i = connections.erase(i);
    delete c;
  }
}

void ConnectionManager::add(Connection *c)
{
  connections.push_back(c);
}

void ConnectionManager::addSelectFDs(Select &s) const
{
  for (ConnectionList::const_iterator i = connections.begin(); i != connections.end(); i++) 
    (*i)->addSelectFDs(s);
}

bool ConnectionManager::isReady(const Select &s) const
{
  for (ConnectionList::const_iterator i = connections.begin(); i != connections.end(); i++) 
    if ((*i)->isReady(s))
      return true;
  return false;
}

void ConnectionManager::processReady(Select &s)
{
  for (ConnectionList::iterator i = connections.begin(); i != connections.end(); ) {
    Connection *c = *i;
    if (!c->processReady(s)) {
      // Close terminated connections
      i = connections.erase(i);
      delete c;
      continue;
    }
    i++;
  }
}

bool ConnectionManager::removeJob(int job)
{
  for (ConnectionList::iterator i = connections.begin(); i != connections.end(); ) {
    RecordConnection *c = dynamic_cast<RecordConnection *>(*i);
    if (c != NULL && c->getJob() == job) {
      // Close terminated connections
      connections.erase(i);
      delete c;
      return true;
    }
    i++;
  }
  return false;
}
