// -*- c++ -*-
/*
  Copyright 2003 John Knottenbelt
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
 
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
*/


#if !defined __SELECT_H
#define __SELECT_H

#include <sys/select.h>		// for fd_set below

class Select;

// Selectable interface
class Selectable {
public:
  virtual void addSelectFDs(Select &) const = 0;
  virtual bool isReady(const Select &) const = 0;
};

// Class wrapping select() system call
class Select {
public:

  Select();

  void clearFDs();

  void addReadFD(int fd);
  void addWriteFD(int fd);
  void addExceptFD(int fd);
  void addAlarm(long tv_sec, long tv_usec);

  int wait();

  bool readyToRead(int fd) const;
  bool readyToWrite(int fd) const;
  bool readyToExcept(int fd) const;
  
private:
  int maxFD;
  fd_set readfds, writefds, exceptfds;
  long tv_sec, tv_usec;

  void setMaxFD(int fd);
};

#endif
